pub fn to_record_batch(result: &QueryResult) -> Option<RecordBatch>Expand description
Convert a QueryResult into an Arrow RecordBatch.
Returns None if the result has zero columns (DDL/DML with no output).
pub fn to_record_batch(result: &QueryResult) -> Option<RecordBatch>Convert a QueryResult into an Arrow RecordBatch.
Returns None if the result has zero columns (DDL/DML with no output).